@@ -60,6 +60,12 @@ DialogSettings::DialogSettings(QWidget *parent) :
 
     //Font
     ui->cbFontSize->setCurrentIndex(settings.value(Core::SETTING_FONTSIZE,0).toInt());
+
+    //Pref Landscape Kb
+    ui->cbPrefLandscapeKb->setCurrentIndex(settings.value(Core::PREF_LANDSCAPE_KB,0).toInt());
+
+    //Pref Portrait Kb
+    ui->cbPrefPortraitKb->setCurrentIndex(settings.value(Core::PREF_PORTRAIT_KB,1).toInt());
 }
 
 DialogSettings::~DialogSettings()
@@ -94,6 +100,12 @@ void DialogSettings::closeOptions()
     //Font size
     settings.setValue(Core::SETTING_FONTSIZE,ui->cbFontSize->currentIndex());
 
+    //Pref Landscape Kb
+    settings.setValue(Core::PREF_LANDSCAPE_KB,ui->cbPrefLandscapeKb->currentIndex());
+
+    //Pref Portrait Kb
+    settings.setValue(Core::PREF_PORTRAIT_KB,ui->cbPrefPortraitKb->currentIndex());
+
     close();
 
     emit settingsChanged(isLanguageChanged);
