@@ -45,15 +45,15 @@ kb_Qwerty::kb_Qwerty(QWidget *parent,bool bStandalone) :
     //Setup all connections
     foreach(QAbstractButton *button, ui->bgDirectInput->buttons())
     {
-        connect(button, SIGNAL(clicked()), this, SLOT(directInputClicked()));
+        connect(button, SIGNAL(released()), this, SLOT(directInputClicked()));
     }
 
-    connect(ui->btNewLine,SIGNAL(clicked()), this, SLOT(newLineClicked()));
-    connect(ui->btDel,SIGNAL(clicked()), this, SLOT(deleteClicked()));
-    connect(ui->btSpace,SIGNAL(clicked()), this, SLOT(spaceClicked()));
-    connect(ui->btShift, SIGNAL(clicked()), this, SLOT(maiuscClicked()));
-    connect(ui->btAccent, SIGNAL(clicked()), this, SLOT(accentClicked()));
-    connect(ui->btSymbol, SIGNAL(clicked()), this, SLOT(symClicked()));
+    connect(ui->btNewLine,SIGNAL(released()), this, SLOT(newLineClicked()));
+    connect(ui->btDel,SIGNAL(released()), this, SLOT(deleteClicked()));
+    connect(ui->btSpace,SIGNAL(released()), this, SLOT(spaceClicked()));
+    connect(ui->btShift, SIGNAL(released()), this, SLOT(maiuscClicked()));
+    connect(ui->btAccent, SIGNAL(released()), this, SLOT(accentClicked()));
+    connect(ui->btSymbol, SIGNAL(released()), this, SLOT(symClicked()));
     //
 
     m_nActiveModifiers = 0;
