@@ -23,6 +23,7 @@
 #include "kb_alfanum.h"
 #include "kb_qwerty.h"
 #include "core.h"
+#include "fastsmswidget.h"
 
 
 KeyboardManager::KeyboardManager(QWidget *parent) :
@@ -46,10 +47,10 @@ KeyboardManager::KeyboardManager(QWidget *parent) :
     m_settings = new QSettings(Core::SETTING_ORG,Core::SETTING_APPNAME,this);
 
     //Open with last used keyboard
-    if(m_settings->value(Core::SETTING_CURRENT_KEYBOARD).toInt() == Core::Qwerty)
-        enableQwerty();
-    else
-        enableAlfaNum();
+//    if(m_settings->value(Core::SETTING_CURRENT_KEYBOARD).toInt() == Core::Qwerty)
+//        enableQwerty();
+//    else
+//        enableAlfanum();
 }
 
 KeyboardManager::~KeyboardManager()
@@ -96,7 +97,7 @@ void KeyboardManager::enableQwerty()
     emit inputStyleChanged(SettingsMenu::QwertyOn);
 }
 
-void KeyboardManager::enableAlfaNum()
+void KeyboardManager::enableAlfanum()
 {
     m_settings->setValue(Core::SETTING_CURRENT_KEYBOARD,Core::Alfanumeric);
     ui->stackedWidget->setCurrentIndex(0);
@@ -119,7 +120,7 @@ void KeyboardManager::settingsChanged(int nStyle)
     }
     else if(nStyle == SettingsMenu::AlfanumOn)
     {
-        enableAlfaNum();
+        enableAlfanum();
 //        if(m_sCurrentOrientation.compare(Core::ORIENTATION_LANDSCAPE)==0)
 //            m_settings->setValue(Core::PREF_LANDSCAPE_KB,Core::Alfanumeric);
 //        else if(m_sCurrentOrientation.compare(Core::ORIENTATION_PORTRAIT)==0)
