@@ -18,9 +18,12 @@
 ****************************************************************************/
 
 #include "settingsmenu.h"
+#include "dialogsettings.h"
+#include "fastsmswidget.h"
 #include <QDebug>
 #include <QSettings>
 
+
 SettingsMenu* SettingsMenu::m_instance;
 
 SettingsMenu::SettingsMenu(QWidget *parent) :
@@ -33,42 +36,54 @@ SettingsMenu::SettingsMenu(QWidget *parent) :
 
     m_aEnableQwerty = new QAction(Core::LBL_QWERTY,this);
     m_aEnableQwerty->setData(QwertyOn);
-    connect(m_aEnableQwerty,SIGNAL(triggered()),this, SLOT(settingsChanged()));
+    connect(m_aEnableQwerty,SIGNAL(triggered()),this, SLOT(actionPerformed()));
     addAction(m_aEnableQwerty);
 
     m_aEnableAlfanum = new QAction(Core::LBL_ALFANUM,this);
     m_aEnableAlfanum->setData(AlfanumOn);
-    connect(m_aEnableAlfanum,SIGNAL(triggered()),this, SLOT(settingsChanged()));
+    connect(m_aEnableAlfanum,SIGNAL(triggered()),this, SLOT(actionPerformed()));
     addAction(m_aEnableAlfanum);
 
     addSeparator();
 
     m_aFastWrite = new QAction(Core::LBL_FASTWRITE_OFF,this);
     m_aFastWrite->setData(FastWriteOff);
-    connect(m_aFastWrite,SIGNAL(triggered()),this, SLOT(settingsChanged()));
+    connect(m_aFastWrite,SIGNAL(triggered()),this, SLOT(actionPerformed()));
     addAction(m_aFastWrite);
 
     addSeparator();
 
     m_aAutoCapitalization = new QAction(Core::LBL_AUTOCAPITALIZATION,this);
     m_aAutoCapitalization->setData(AutoCapitalize);
-    connect(m_aAutoCapitalization,SIGNAL(triggered()),this, SLOT(settingsChanged()));
+    connect(m_aAutoCapitalization,SIGNAL(triggered()),this, SLOT(actionPerformed()));
     addAction(m_aAutoCapitalization);
 
     m_aUpperCase = new QAction(Core::LBL_UPPERCASE,this);
     m_aUpperCase->setData(UpperCase);
-    connect(m_aUpperCase,SIGNAL(triggered()),this, SLOT(settingsChanged()));
+    connect(m_aUpperCase,SIGNAL(triggered()),this, SLOT(actionPerformed()));
     addAction(m_aUpperCase);
 
     m_aLowerCase = new QAction(Core::LBL_LOWERCASE,this);
     m_aLowerCase->setData(LowerCase);
-    connect(m_aLowerCase,SIGNAL(triggered()),this, SLOT(settingsChanged()));
+    connect(m_aLowerCase,SIGNAL(triggered()),this, SLOT(actionPerformed()));
     addAction(m_aLowerCase);
 
     m_aDigit = new QAction(Core::LBL_DIGIT,this);
     m_aDigit->setData(DigitOnly);
-    connect(m_aDigit,SIGNAL(triggered()),this, SLOT(settingsChanged()));
+    connect(m_aDigit,SIGNAL(triggered()),this, SLOT(actionPerformed()));
     addAction(m_aDigit);
+
+    addSeparator();
+
+    m_aOptions = new QAction("Settings",this);
+    m_aOptions->setData(Options);
+    connect(m_aOptions,SIGNAL(triggered()),this, SLOT(actionPerformed()));
+    addAction(m_aOptions);
+
+    m_aNewWord = new QAction("New Word",this);
+    m_aNewWord->setData(NewWord);
+    connect(m_aNewWord,SIGNAL(triggered()),this, SLOT(actionPerformed()));
+    addAction(m_aNewWord);
     //
 
     //Synchronize with active kb
@@ -98,7 +113,7 @@ SettingsMenu::~SettingsMenu()
         drop();
 }
 
-void SettingsMenu::settingsChanged()
+void SettingsMenu::actionPerformed()
 {
     QAction *action = qobject_cast<QAction *>(sender());
 
@@ -128,6 +143,10 @@ void SettingsMenu::settingsChanged()
     case AlfanumOn:
         alfanumEnabled();
         break;
+    case Options:
+        break;
+    case NewWord:
+        break;
     }
 
     emit inputStyleChanged(nAction);
